@@ -73,8 +73,8 @@ sub _all_columns_except {
 __PACKAGE__->load_components('+Rapi::Blog::DB::Component::ResultSet::ListAPI');
 
 sub _api_default_params {{ limit => 20 }}
-sub _api_param_arg_order { [qw/search tag page limit sort category/] } 
-
+sub _api_param_arg_order { [qw/search tag page limit sort category section_id/] } 
+sub _api_params_undef_map {{ section_id => 'none' }};
 
 # Method exposed to templates:
 
@@ -128,6 +128,16 @@ sub list_posts {
 		}
 	}
   
+  if(exists $P->{section_id}) {
+    $Rs = $Rs->search_rs({ 'me.section_id' => $P->{section_id} });
+  }
+  elsif($P->{under_section_id}) {
+    $Rs = $Rs->search_rs(
+      { 'trk_section_posts.section_id' => $P->{under_section_id} },
+      { join => 'trk_section_posts' }
+    );
+  }
+  
   return $Rs->_list_api
 }
 
